# Core Concepts

This section covers the fundamental principles and features of WD-DI.

* [Separation of Concerns](./separation-of-concerns.md)
* [Component-Based Design](./component-based-design.md)
* [Constructor Injection](./constructor-injection.md)
* [Service Lifetimes](./lifetimes.md)
* [Configuration & Options](./configuration.md) 